abacusai.hosted_database — AbacusAI documentation

# abacusai.hosted_database

## Classes

`HostedDatabase` | Hosted Database

## Module Contents

class abacusai.hosted_database.HostedDatabase(client, hostedDatabaseId=None, displayName=None, createdAt=None, updatedAt=None, lifecycle=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Hosted Database

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - hostedDatabaseId (id) – The ID of the hosted database

    - displayName (str) – The name of the hosted database

    - createdAt (str) – The creation timestamp

    - updatedAt (str) – The last update timestamp

    - lifecycle (str) – The lifecycle of the hosted database

  hosted_database_id = None
  display_name = None
  created_at = None
  updated_at = None
  lifecycle = None
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict